@@ -279,7 +279,7 @@ shutdown_task (void *cls)
   }
   if (NULL != main_context.id_op)
   {
-    GNUNET_IDENTITY_cancel (main_context.id_op);
+    GNUNET_IDENTITY_ego_lookup_cancel (main_context.id_op);
     main_context.id_op = NULL;
   }
   if (NULL != main_context.identity)
@@ -647,9 +647,7 @@ monitor_zone_records (void *cls,
  */
 static void
 handle_sks_zone_identity (void *cls,
-                          struct GNUNET_IDENTITY_Ego *ego,
-                          void **ctx,
-                          const char *name)
+                          struct GNUNET_IDENTITY_Ego *ego)
 {
   main_context.id_op = NULL;
 
@@ -722,6 +720,7 @@ run (void *cls)
   unsigned long long window_width;
   unsigned long long window_height;
   int maximized;
+  char *default_ego_name;
 
   ml = cls;
   /* setup main context */
@@ -857,7 +856,17 @@ run (void *cls)
                                              "MAX_PARALLEL_REQUESTS",
                                              &req_parallel))
     req_parallel = DEFAULT_MAX_PARALLEL_REQUESTS;
-
+  if (GNUNET_OK !=
+      GNUNET_CONFIGURATION_get_value_string (main_context.cfg,
+                                             "fs-sks",
+                                             "DEFAULT_IDENTITY",
+                                             &default_ego_name))
+  {
+    GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+                "Please set DEFAULT_IDENTITY under [fs-sks]\n");
+    GNUNET_GTK_main_loop_quit (cls);
+    return;
+  }
   /* initialize file-sharing */
   fs = GNUNET_FS_start (main_context.cfg,
                         "gnunet-fs-gtk",
@@ -883,10 +892,11 @@ run (void *cls)
   main_context.gns = GNUNET_GNS_connect (main_context.cfg);
   main_context.identity =
     GNUNET_IDENTITY_connect (main_context.cfg, &non_null_cb, NULL);
-  main_context.id_op = GNUNET_IDENTITY_get (main_context.identity,
-                                            "fs-sks",
+  main_context.id_op = GNUNET_IDENTITY_ego_lookup (main_context.cfg,
+                                            default_ego_name,
                                             &handle_sks_zone_identity,
                                             NULL);
+  GNUNET_free (default_ego_name);
 #if HAVE_LIBUNIQUE
   unique_app_watch_window (unique_app, GTK_WINDOW (main_context.main_window));
   g_signal_connect (unique_app,
