@@ -248,7 +248,7 @@ struct GNUNET_GTK_MainWindowContext
   /**
    * Operation we use to determine namespace resolution domain.
    */
-  struct GNUNET_IDENTITY_Operation *id_op;
+  struct GNUNET_IDENTITY_EgoLookup *id_op;
 
   /**
    * Our zone for SKS operations.  Can be NULL.
