@@ -36,7 +36,6 @@
  *         #GNUNET_SYSERR if we failed to parse the URI
  */
 int
-GNUNET_FS_GTK_handle_uri_string (const char *uris,
-				 guint anonymity_level);
+GNUNET_FS_GTK_handle_uri_string (const char *uris, guint anonymity_level);
 
 #endif
