@@ -30,16 +30,19 @@
  * for gnunet-gtk.
  */
 static const struct GNUNET_OS_ProjectData gtk_pd =
-  {.libname = "libgnunetgtk",
-   .project_dirname = "gnunet",
-   .binary_name = "gnunet-fs-gtk",
-   .env_varname = "GNUNET_GTK_PREFIX",
-   .env_varname_alt = "GNUNET_PREFIX",
-   .base_config_varname = "GNUNET_BASE_CONFIG",
-   .bug_email = "gnunet-developers@gnu.org",
-   .homepage = "http://www.gnu.org/s/gnunet/",
-   .config_file = "gnunet.conf",
-   .user_config_file = "~/.config/gnunet.conf"};
+{.libname = "libgnunetgtk",
+ .project_dirname = "gnunet",
+ .binary_name = "gnunet-fs-gtk",
+ .env_varname = "GNUNET_GTK_PREFIX",
+ .env_varname_alt = "GNUNET_PREFIX",
+ .base_config_varname = "GNUNET_BASE_CONFIG",
+ .bug_email = "gnunet-developers@gnu.org",
+ .homepage = "http://www.gnu.org/s/gnunet/",
+ .config_file = "gnunet.conf",
+ .user_config_file = "~/.config/gnunet.conf",
+ .gettext_domain = "gnunet-gtk",
+ .version = PACKAGE_VERSION,
+ .is_gnu = 1};
 
 
 /**
@@ -55,7 +58,8 @@ GNUNET_GTK_project_data_default (void)
 /**
  * Initialize libgnunetgtk.
  */
-void __attribute__ ((constructor)) GNUNET_GTK_init ()
+void __attribute__ ((constructor))
+GNUNET_GTK_init (void)
 {
   GNUNET_OS_init (&gtk_pd);
 }
