@@ -1,22 +1,22 @@
 /*
-  * This file is part of GNUnet
-  * Copyright (C) 2009-2013 GNUnet e.V.
-  *
-  * GNUnet is free software; you can redistribute it and/or modify
-  * it under the terms of the GNU General Public License as published
-  * by the Free Software Foundation; either version 3, or (at your
-  * option) any later version.
-  *
-  * GNUnet is distributed in the hope that it will be useful, but
-  * WITHOUT ANY WARRANTY; without even the implied warranty of
-  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  * General Public License for more details.
-  *
-  * You should have received a copy of the GNU General Public License
-  * along with GNUnet; see the file COPYING.  If not, write to the
-  * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  * Boston, MA 02110-1301, USA.
-  */
+ * This file is part of GNUnet
+ * Copyright (C) 2009-2013 GNUnet e.V.
+ *
+ * GNUnet is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published
+ * by the Free Software Foundation; either version 3, or (at your
+ * option) any later version.
+ *
+ * GNUnet is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with GNUnet; see the file COPYING.  If not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 
 /**
  * @file namestore/plugin_gtk_namestore_phone.c
@@ -133,8 +133,9 @@ phone_validate (void *cls, GtkBuilder *builder)
       (GNUNET_OK !=
        GNUNET_CRYPTO_ecdsa_public_key_from_string (preedit,
                                                    strlen (preedit),
-                                                   &pub)))
+                                                   &pub.ecdsa_key)))
     return GNUNET_SYSERR;
+  pub.type = GNUNET_IDENTITY_TYPE_ECDSA;
   return GNUNET_OK;
 }
 
@@ -151,9 +152,9 @@ libgnunet_plugin_gtk_namestore_phone_init (void *cls)
   struct GNUNET_GTK_NAMESTORE_PluginEnvironment *env = cls;
   struct GNUNET_GTK_NAMESTORE_PluginFunctions *plugin;
   static struct GNUNET_GTK_NAMESTORE_Symbol symbols[] =
-    {{"GNS_edit_dialog_phone_peer_entry_changed_cb",
-      G_CALLBACK (GNS_edit_dialog_phone_peer_entry_changed_cb)},
-     {NULL, NULL}};
+  {{"GNS_edit_dialog_phone_peer_entry_changed_cb",
+    G_CALLBACK (GNS_edit_dialog_phone_peer_entry_changed_cb)},
+   {NULL, NULL}};
 
   plugin = GNUNET_new (struct GNUNET_GTK_NAMESTORE_PluginFunctions);
   plugin->cls = env;
@@ -182,4 +183,5 @@ libgnunet_plugin_gtk_namestore_phone_done (void *cls)
   return NULL;
 }
 
+
 /* end of plugin_gtk_namestore_phone.c */
