@@ -1,22 +1,22 @@
 /*
-  * This file is part of GNUnet
-  * Copyright (C) 2009-2013 GNUnet e.V.
-  *
-  * GNUnet is free software; you can redistribute it and/or modify
-  * it under the terms of the GNU General Public License as published
-  * by the Free Software Foundation; either version 3, or (at your
-  * option) any later version.
-  *
-  * GNUnet is distributed in the hope that it will be useful, but
-  * WITHOUT ANY WARRANTY; without even the implied warranty of
-  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  * General Public License for more details.
-  *
-  * You should have received a copy of the GNU General Public License
-  * along with GNUnet; see the file COPYING.  If not, write to the
-  * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  * Boston, MA 02110-1301, USA.
-  */
+ * This file is part of GNUnet
+ * Copyright (C) 2009-2013 GNUnet e.V.
+ *
+ * GNUnet is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published
+ * by the Free Software Foundation; either version 3, or (at your
+ * option) any later version.
+ *
+ * GNUnet is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with GNUnet; see the file COPYING.  If not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ */
 
 /**
  * @file namestore/plugin_gtk_namestore_vpn.c
@@ -36,7 +36,7 @@
  */
 static void
 GNS_edit_dialog_vpn_peer_entry_changed_cb (GtkEditable *entry,
-					   gpointer user_data)
+                                           gpointer user_data)
 {
   struct GNUNET_GTK_NAMESTORE_PluginEnvironment *edc = user_data;
 
@@ -54,35 +54,39 @@ GNS_edit_dialog_vpn_peer_entry_changed_cb (GtkEditable *entry,
  * @param builder the edit dialog's builder
  */
 static void
-vpn_load (void *cls,
-        gchar *n_value,
-        GtkBuilder *builder)
+vpn_load (void *cls, gchar *n_value, GtkBuilder *builder)
 {
   char s_peer[53 + 1];
   char s_serv[253 + 1];
   unsigned int proto;
 
-  if (3 != SSCANF (n_value,
-                   "%u %53s %253s",
-                   &proto, s_peer, s_serv))
+  if (3 != sscanf (n_value, "%u %53s %253s", &proto, s_peer, s_serv))
   {
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                _("Unable to parse VPN record string `%s'\n"),
+                _ ("Unable to parse VPN record string `%s'\n"),
                 n_value);
     return;
   }
-  gtk_entry_set_text (GTK_ENTRY (gtk_builder_get_object (builder,
-                                                         "edit_dialog_vpn_identifier_entry")),
-                      s_serv);
-  gtk_entry_set_text (GTK_ENTRY (gtk_builder_get_object (builder,
-                                                         "edit_dialog_vpn_peer_entry")),
+  gtk_entry_set_text (
+    GTK_ENTRY (
+      gtk_builder_get_object (builder, "edit_dialog_vpn_identifier_entry")),
+    s_serv);
+  gtk_entry_set_text (GTK_ENTRY (
+                        gtk_builder_get_object (builder,
+                                                "edit_dialog_vpn_peer_entry")),
                       s_peer);
   if (IPPROTO_UDP == proto)
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder,
-                                                                             "edit_dialog_vpn_protocol_udp_radiobutton")), TRUE);
+    gtk_toggle_button_set_active (
+      GTK_TOGGLE_BUTTON (
+        gtk_builder_get_object (builder,
+                                "edit_dialog_vpn_protocol_udp_radiobutton")),
+      TRUE);
   else
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder,
-                                                                             "edit_dialog_vpn_protocol_tcp_radiobutton")), TRUE);
+    gtk_toggle_button_set_active (
+      GTK_TOGGLE_BUTTON (
+        gtk_builder_get_object (builder,
+                                "edit_dialog_vpn_protocol_tcp_radiobutton")),
+      TRUE);
 }
 
 
@@ -95,8 +99,7 @@ vpn_load (void *cls,
  * @return record value as a string, as specified in the dialog
  */
 static gchar *
-vpn_store (void *cls,
-         GtkBuilder *builder)
+vpn_store (void *cls, GtkBuilder *builder)
 {
   GtkEntry *entry;
   const gchar *identifier;
@@ -104,14 +107,18 @@ vpn_store (void *cls,
   unsigned int proto;
   char *result;
 
-  entry = GTK_ENTRY (gtk_builder_get_object (builder,
-                                             "edit_dialog_vpn_identifier_entry"));
+  entry = GTK_ENTRY (
+    gtk_builder_get_object (builder, "edit_dialog_vpn_identifier_entry"));
   identifier = gtk_entry_get_text (entry);
-  entry = GTK_ENTRY (gtk_builder_get_object (builder,
-                                             "edit_dialog_vpn_peer_entry"));
+  entry =
+    GTK_ENTRY (gtk_builder_get_object (builder, "edit_dialog_vpn_peer_entry"));
   peer = gtk_entry_get_text (entry);
-  proto = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder,
-                                                                                   "edit_dialog_vpn_protocol_tcp_radiobutton"))) ? IPPROTO_TCP : IPPROTO_UDP;
+  proto =
+    gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (
+      gtk_builder_get_object (builder,
+                              "edit_dialog_vpn_protocol_tcp_radiobutton")))
+      ? IPPROTO_TCP
+      : IPPROTO_UDP;
   GNUNET_asprintf (&result,
                    "%u %s %s",
                    proto,
@@ -133,21 +140,20 @@ vpn_store (void *cls,
  * @return #GNUNET_OK if there is a valid record value in the dialog
  */
 static int
-vpn_validate (void *cls,
-            GtkBuilder *builder)
+vpn_validate (void *cls, GtkBuilder *builder)
 {
   GtkEditable *entry;
   const gchar *preedit;
   struct GNUNET_CRYPTO_EddsaPublicKey pk;
 
-  entry = GTK_EDITABLE (gtk_builder_get_object (builder,
-						"edit_dialog_vpn_peer_entry")),
+  entry = GTK_EDITABLE (
+    gtk_builder_get_object (builder, "edit_dialog_vpn_peer_entry")),
   preedit = gtk_editable_get_chars (entry, 0, -1);
-  if ( (NULL == preedit) ||
-       (GNUNET_OK !=
-	GNUNET_CRYPTO_eddsa_public_key_from_string (preedit,
-                                                    strlen (preedit),
-                                                    &pk)) )
+  if ((NULL == preedit) ||
+      (GNUNET_OK !=
+       GNUNET_CRYPTO_eddsa_public_key_from_string (preedit,
+                                                   strlen (preedit),
+                                                   &pk)))
     return GNUNET_SYSERR;
   return GNUNET_OK;
 }
@@ -164,11 +170,10 @@ libgnunet_plugin_gtk_namestore_vpn_init (void *cls)
 {
   struct GNUNET_GTK_NAMESTORE_PluginEnvironment *env = cls;
   struct GNUNET_GTK_NAMESTORE_PluginFunctions *plugin;
-  static struct GNUNET_GTK_NAMESTORE_Symbol symbols[] = {
-    { "GNS_edit_dialog_vpn_peer_entry_changed_cb",
-      G_CALLBACK (GNS_edit_dialog_vpn_peer_entry_changed_cb) },
-    { NULL, NULL }
-  };
+  static struct GNUNET_GTK_NAMESTORE_Symbol symbols[] =
+    {{"GNS_edit_dialog_vpn_peer_entry_changed_cb",
+      G_CALLBACK (GNS_edit_dialog_vpn_peer_entry_changed_cb)},
+     {NULL, NULL}};
 
   plugin = GNUNET_new (struct GNUNET_GTK_NAMESTORE_PluginFunctions);
   plugin->cls = env;
